.. _pycares:


*************************************************
:py:mod:`pycares` --- Python interface to c-ares.
*************************************************

.. py:module:: pycares
    :platform: POSIX, Windows
    :synopsis: Python interface to c-ares.

.. seealso::
    `c-ares source code
    <http://github.com/bagder/c-ares>`_.


Objects
*******

.. toctree::
    :maxdepth: 2
    :titlesonly:

    channel
    utils
    constants
    errno
    event_loops

